summaryrefslogtreecommitdiffstats
path: root/c++/src/H5Exception.h
diff options
context:
space:
mode:
authorBinh-Minh Ribler <bmribler@hdfgroup.org>2004-08-20 04:30:45 (GMT)
committerBinh-Minh Ribler <bmribler@hdfgroup.org>2004-08-20 04:30:45 (GMT)
commitb142a4144862b22c37c27aa11e2ee519a08ede2f (patch)
treebc3ad3c3c66d9bbf4170c0bc597ce889b886e684 /c++/src/H5Exception.h
parent4a04b0c05c608de05c69c33a6dced509d04cde09 (diff)
downloadhdf5-b142a4144862b22c37c27aa11e2ee519a08ede2f.zip
hdf5-b142a4144862b22c37c27aa11e2ee519a08ede2f.tar.gz
hdf5-b142a4144862b22c37c27aa11e2ee519a08ede2f.tar.bz2
[svn-r9128] Purpose: Code updating
Description: Renamed some private members and member functions appropriately. Platforms tested: SunOS 5.7 (arabica) Linux 2.4 (eirene)
Diffstat (limited to 'c++/src/H5Exception.h')
-rw-r--r--c++/src/H5Exception.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/c++/src/H5Exception.h b/c++/src/H5Exception.h
index 073827e..c67ca3f 100644
--- a/c++/src/H5Exception.h
+++ b/c++/src/H5Exception.h
@@ -27,21 +27,15 @@ namespace H5 {
class H5_DLLCPP Exception {
public:
- // Default constructor
- Exception();
-
// Creates an exception with a function name where the failure occurs
// and an optional detailed message
Exception(const string func_name, const string message = DEFAULT_MSG);
- // copy constructor
- Exception( const Exception& orig);
-
- // Returns the character string that describes an error specified by
+ // Returns a character string that describes the error specified by
// a major error number.
string getMajorString( hid_t err_major_id ) const;
- // Returns the character string that describes an error specified by
+ // Returns a character string that describes the error specified by
// a minor error number.
string getMinorString( hid_t err_minor_id ) const;
@@ -72,6 +66,12 @@ class H5_DLLCPP Exception {
// Prints the error stack in a default manner.
virtual void printError( FILE* stream = NULL ) const;
+ // Default constructor
+ Exception();
+
+ // copy constructor
+ Exception( const Exception& orig);
+
// virtual Destructor
virtual ~Exception();
@@ -82,81 +82,81 @@ class H5_DLLCPP Exception {
#if defined(WIN32)
#pragma warning(disable: 4251)
#endif
- string detailMessage;
- string funcName;
+ string detail_message;
+ string func_name;
+
protected:
// Default value for detailMessage
static const string DEFAULT_MSG;
-
};
class H5_DLLCPP FileIException : public Exception {
public:
+ FileIException( const string func_name, const string message = DEFAULT_MSG);
FileIException();
- FileIException(const string func_name, const string message = DEFAULT_MSG);
virtual ~FileIException();
};
class H5_DLLCPP GroupIException : public Exception {
public:
+ GroupIException( const string func_name, const string message = DEFAULT_MSG);
GroupIException();
- GroupIException(const string func_name, const string message = DEFAULT_MSG);
virtual ~GroupIException();
};
class H5_DLLCPP DataSpaceIException : public Exception {
public:
- DataSpaceIException();
DataSpaceIException(const string func_name, const string message = DEFAULT_MSG);
+ DataSpaceIException();
virtual ~DataSpaceIException();
};
class H5_DLLCPP DataTypeIException : public Exception {
public:
- DataTypeIException();
DataTypeIException(const string func_name, const string message = DEFAULT_MSG);
+ DataTypeIException();
virtual ~DataTypeIException();
};
class H5_DLLCPP PropListIException : public Exception {
public:
- PropListIException();
PropListIException(const string func_name, const string message = DEFAULT_MSG);
+ PropListIException();
virtual ~PropListIException();
};
class H5_DLLCPP DataSetIException : public Exception {
public:
- DataSetIException();
DataSetIException(const string func_name, const string message = DEFAULT_MSG);
+ DataSetIException();
virtual ~DataSetIException();
};
class H5_DLLCPP AttributeIException : public Exception {
public:
- AttributeIException();
AttributeIException(const string func_name, const string message = DEFAULT_MSG);
+ AttributeIException();
virtual ~AttributeIException();
};
class H5_DLLCPP ReferenceException : public Exception {
public:
+ ReferenceException(const string func_name, const string message = DEFAULT_MSG);
ReferenceException();
- ReferenceException(const string func_name, const string message=DEFAULT_MSG);
virtual ~ReferenceException();
};
class H5_DLLCPP LibraryIException : public Exception {
public:
+ LibraryIException(const string func_name, const string message = DEFAULT_MSG);
LibraryIException();
- LibraryIException(const string func_name, const string message=DEFAULT_MSG);
virtual ~LibraryIException();
};
class H5_DLLCPP IdComponentException : public Exception {
public:
+ IdComponentException(const string func_name, const string message = DEFAULT_MSG);
IdComponentException();
- IdComponentException(const string func_name, const string message=DEFAULT_MSG);
virtual ~IdComponentException();
};
@@ -82,81 +82,81 @@ class H5_DLLCPP Exception {
protected:
- // Default value for detailMessage
+ // Default value for detail_message
static const string DEFAULT_MSG;